@@ -68,10 +68,14 @@ You should not be using this module directly.
 
 =head1 AUTHORS
 
+The original authors are
 Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>
 and
 Christophe Dehaudt F<E<lt>Christophe.Dehaudt@teamlog.frE<gt>>.
 
+Send bug reports, suggestions, problems or questions to
+Jason Purdy F<E<lt>Jason@Purdy.INFOE<gt>>
+
 =head1 SEE ALSO
 
 CGI::MxScreen(3).
