@@ -66,10 +66,14 @@ defined C<CGI::MxScreen> exceptions.
 
 =head1 AUTHORS
 
+The original authors are
 Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>
 and
 Christophe Dehaudt F<E<lt>Christophe.Dehaudt@teamlog.frE<gt>>.
 
+Send bug reports, suggestions, problems or questions to
+Jason Purdy F<E<lt>Jason@Purdy.INFOE<gt>>
+
 =head1 SEE ALSO
 
 CGI::MxScreen::Exception::Bounce(3).
